@@ -17,9 +17,9 @@ pass_cli_config = click.make_pass_decorator(CLIConfig, ensure=True)
 
 def run_steps(steps, fail_message, success_message):
     """Run a series of steps."""
-    for test in steps:
-        click.secho(message=test.message, fg="green")
-        result = test.execute()
+    for step in steps:
+        click.secho(message=step.message, fg="green")
+        result = step.execute()
         if result.status_code > 0:
             if result.error:
                 fail_message = fail_message + f"\nErrors: {result.error}"
@@ -28,6 +28,13 @@ def run_steps(steps, fail_message, success_message):
 
             click.secho(fail_message, fg="red")
             exit(1)
+        elif result.warning:
+            if result.error:
+                fail_message = fail_message + f"\nErrors: {result.error}"
+            if result.output:
+                fail_message = fail_message + f"\nOutput: {result.output}"
+
+            click.secho(fail_message, fg="yellow")
         elif result.output:
             click.secho(message=result.output, fg="green")
     else:
